package com.ygtx.gxt.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ygtx.common.annotation.Log;
import com.ygtx.common.core.controller.BaseController;
import com.ygtx.common.core.domain.AjaxResult;
import com.ygtx.common.enums.BusinessType;
import com.ygtx.gxt.domain.GxtRepairOrderFlow;
import com.ygtx.gxt.service.IGxtRepairOrderFlowService;
import com.ygtx.common.utils.poi.ExcelUtil;
import com.ygtx.common.core.page.TableDataInfo;

/**
 * 维修工单流转记录Controller
 * 
 * @author ouyj
 * @date 2025-10-30
 */
@RestController
@RequestMapping("/gxt/repairOrderFlow")
public class GxtRepairOrderFlowController extends BaseController
{
    @Autowired
    private IGxtRepairOrderFlowService gxtRepairOrderFlowService;

    /**
     * 查询维修工单流转记录列表
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:list')")
    @GetMapping("/list")
    public TableDataInfo list(GxtRepairOrderFlow gxtRepairOrderFlow)
    {
        startPage();
        List<GxtRepairOrderFlow> list = gxtRepairOrderFlowService.selectGxtRepairOrderFlowList(gxtRepairOrderFlow);
        return getDataTable(list);
    }

    /**
     * 导出维修工单流转记录列表
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:export')")
    @Log(title = "维修工单流转记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, GxtRepairOrderFlow gxtRepairOrderFlow)
    {
        List<GxtRepairOrderFlow> list = gxtRepairOrderFlowService.selectGxtRepairOrderFlowList(gxtRepairOrderFlow);
        ExcelUtil<GxtRepairOrderFlow> util = new ExcelUtil<GxtRepairOrderFlow>(GxtRepairOrderFlow.class);
        util.exportExcel(response, list, "维修工单流转记录数据");
    }

    /**
     * 获取维修工单流转记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(gxtRepairOrderFlowService.selectGxtRepairOrderFlowById(id));
    }

    /**
     * 新增维修工单流转记录
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:add')")
    @Log(title = "维修工单流转记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody GxtRepairOrderFlow gxtRepairOrderFlow)
    {
        return toAjax(gxtRepairOrderFlowService.insertGxtRepairOrderFlow(gxtRepairOrderFlow));
    }

    /**
     * 修改维修工单流转记录
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:edit')")
    @Log(title = "维修工单流转记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody GxtRepairOrderFlow gxtRepairOrderFlow)
    {
        return toAjax(gxtRepairOrderFlowService.updateGxtRepairOrderFlow(gxtRepairOrderFlow));
    }

    /**
     * 删除维修工单流转记录
     */
    @PreAuthorize("@ss.hasPermi('gxt:repairOrderFlow:remove')")
    @Log(title = "维修工单流转记录", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(gxtRepairOrderFlowService.deleteGxtRepairOrderFlowByIds(ids));
    }
}
